==> dragon-17.11.90.tar.xz: dragon-17.11.90/src/app/timeLabel.h <==
/***********************************************************************
 * Copyright 2005  Max Howell <max.howell@methylblue.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/

#ifndef TIMELABEL_H
#define TIMELABEL_H

#include <QLabel>

class TimeLabel : public QLabel
{
    Q_OBJECT
public:
    explicit TimeLabel( QWidget *parent );
    virtual ~TimeLabel();
    void mousePressEvent( QMouseEvent * ) Q_DECL_OVERRIDE;
    void updateTime();
    enum TimeFormats { SHOW_REMAINING, SHOW_COMPLETED };
public slots:
    void setCurrentTime( qint64 );
    void setTotalTime( qint64 );
private:
    TimeFormats m_timeFormat;
    qint64 m_currentTime;
    qint64 m_totalTime;
};

#endif

==> dragon-19.11.80.tar.xz: dragon-19.11.80/src/app/timeLabel.h <==
/***********************************************************************
 * Copyright 2005  Max Howell <max.howell@methylblue.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************/

#ifndef TIMELABEL_H
#define TIMELABEL_H

#include <QLabel>

class TimeLabel : public QLabel
{
    Q_OBJECT
public:
    explicit TimeLabel( QWidget *parent );
    ~TimeLabel() override;
    void mousePressEvent( QMouseEvent * ) override;
    void updateTime();
    enum TimeFormats { SHOW_REMAINING, SHOW_COMPLETED };
public Q_SLOTS:
    void setCurrentTime( qint64 );
    void setTotalTime( qint64 );
private:
    TimeFormats m_timeFormat;
    qint64 m_currentTime;
    qint64 m_totalTime;
};

#endif
